Preview of the proposed up-rust native-frame-model branch (up-rust b6b99c6d, up-spec f0e9b17) — not released documentation. branch · write-up

Enum UFrameAbiError

pub enum UFrameAbiError {
    CapacityExceeded {
        field: &'static str,
    },
    InvalidProfile(String),
    Metadata(UFrameMetadataError),
}
Errors returned by ABI profile conversions.

Variants



CapacityExceeded

A value exceeds a fixed capacity of this profile.

Fields

field: &'static str

Name of the offending field.



InvalidProfile(String)

The struct is not a structurally valid profile v1 value.



Metadata(UFrameMetadataError)

The metadata violates frame invariants.