pub enum UFrameAbiError {
CapacityExceeded {
field: &'static str,
},
InvalidProfile(String),
Metadata(UFrameMetadataError),
}Expand description
Errors returned by ABI profile conversions.
Variants
CapacityExceeded
A value exceeds a fixed capacity of this profile.
InvalidProfile(String)
The struct is not a structurally valid profile v1 value.
Metadata(UFrameMetadataError)
The metadata violates frame invariants.